<!-- SPDX-FileCopyrightText: 2025 German Aerospace Center <amiris@dlr.de>

SPDX-License-Identifier: CC0-1.0 -->

# Changelog
## [v2.0.0](https://gitlab.com/dlr-ve/esy/amiris/extensions/priceforecast/-/releases/v2.0.0) 2025-06-12
## Changed
- **Breaking**: Rename of entry point to `amiris-priceforecast` #12 (@dlr_fn, @dlr-cjs)
- **Breaking**: Rename of module `main.py` to `workflow.py` !4 (@dlr_fn, @dlr-cjs)

## Fixed
- Dependency specification in `pyproject.toml` #12 (@dlr_fn, @dlr-cjs)

## [v1.0](https://gitlab.com/dlr-ve/esy/amiris/extensions/priceforecast/-/releases/v1.0.0) 2025-02-25
_Initial Release._
